from nose import tools
from sixfeetup.todo.ticket import Ticket

PRIORITIES = ['emergency', 'scheduled', 'critical', 'major', 'minor']

def ticket_repr_test():
    """Does the ticket repr properly?
    """
    ticket = Ticket(
        10,
        "This is a todo item",
        "Week of 06/21/10",
        "Blocker",
        "01-Monday",
        "1",
        )
    tools.assert_equal(
        ticket.__repr__(),
        "<Ticket #10>",
        )


def list_tickets_sort_test():
    """Test sorting with all the fields
    """
    tickets = []
    ta = tickets.append
    ta(Ticket(
        55, "This is a todo item", "Week of 06/28/10", "emergency",
        "01-Monday", "10", PRIORITIES))
    ta(Ticket(
        5, "Done by friday", "Week of 06/21/10", "emergency",
        "01-Monday", "10", PRIORITIES))
    ta(Ticket(
        7, "This is a todo item", "Ongoing", "critical",
        "04-Thursday", "10", PRIORITIES))
    ta(Ticket(
        10, "Done monday first", "Week of 06/21/10", "scheduled",
        "03-Wednesday", "10", PRIORITIES))
    ta(Ticket(
        99, "This would be first", "Week of 06/21/10", "critical",
        "01-Monday", "10", PRIORITIES))
    ta(Ticket(
        9, "Last for week of the 21st", "Week of 06/21/10", "major",
        "02-Tuesday", "10", PRIORITIES))
    ta(Ticket(
        88, "Done monday 2nd", "Week of 06/21/10", "minor",
        "01-Monday", "10", PRIORITIES))
    # they are in the order we added them as
    tools.assert_equal(
        repr(tickets),
        ('[<Ticket #55>, <Ticket #5>, <Ticket #7>, <Ticket #10>, '
         '<Ticket #99>, <Ticket #9>, <Ticket #88>]'),
        "You messed up the sort order",
    )
    # now let's sort and test
    tickets.sort()
    tools.assert_equal(
        repr(tickets),
        ('[<Ticket #5>, <Ticket #99>, <Ticket #88>, <Ticket #9>, '
         '<Ticket #10>, <Ticket #55>, <Ticket #7>]'),
        "Order is not applying to the list properly: %s" % tickets,
    )


def compare_milestone_test():
    """Compare only the milestones
    """
    ticket1 = Ticket(
        88,
        "Done monday 2nd",
        "Week of 06/21/10",
        "minor",
        "01-Monday",
        "10",
        )
    ticket2 = Ticket(
        88,
        "Done monday 2nd",
        "Week of 06/28/10",
        "minor",
        "01-Monday",
        "10",
        )
    ticket3 = Ticket(
        88,
        "Done monday 2nd",
        "Ongoing Work",
        "minor",
        "01-Monday",
        "10",
        )
    ticket4 = Ticket(
        88,
        "Done monday 2nd",
        "Alphabet",
        "minor",
        "01-Monday",
        "10",
        )
    # 6/21 v. 6/28
    tools.assert_equal(-1, cmp(ticket1, ticket2))
    # 6/28 v. Ongoing
    tools.assert_equal(-1, cmp(ticket2, ticket3))
    # Ongoing v. Alpha
    tools.assert_equal(1, cmp(ticket3, ticket4))


def compare_flag_test():
    """This test is kind of pointless now. Since they start with a number.
    """
    ticket1 = Ticket(
        88,
        "Summary",
        "Moot",
        "Moot",
        "01-Monday",
        "10",
        )
    ticket2 = Ticket(
        88,
        "Summary",
        "Moot",
        "Moot",
        "02-Tuesday",
        "10",
        )
    ticket3 = Ticket(
        88,
        "Summary",
        "Moot",
        "Moot",
        "03-Wednesday",
        "10",
        )
    ticket4 = Ticket(
        88,
        "Summary",
        "Moot",
        "Moot",
        "04-Thursday",
        "10",
        )
    # Monday vs. Tuesday
    tools.assert_equal(-1, cmp(ticket1, ticket2))
    # Thursday vs. Monday
    tools.assert_equal(1, cmp(ticket4, ticket1))
    # Wednesday vs. Thursday
    tools.assert_equal(-1, cmp(ticket3, ticket4))


def compare_priority_test():
    """The priorities should match the order that is set in Trac admin
    """
    scheduled_ticket = Ticket(
        88,
        "Summary",
        "Moot",
        "scheduled",
        "03-Wednesday",
        "10",
        PRIORITIES,
        )
    emergency_ticket = Ticket(
        88,
        "Summary",
        "Moot",
        "emergency",
        "03-Wednesday",
        "10",
        PRIORITIES,
        )
    minor_ticket = Ticket(
        88,
        "Summary",
        "Moot",
        "minor",
        "03-Wednesday",
        "10",
        PRIORITIES,
        )
    major_ticket = Ticket(
        88,
        "Summary",
        "Moot",
        "major",
        "03-Wednesday",
        "10",
        PRIORITIES,
        )
    critical_ticket = Ticket(
        88,
        "Summary",
        "Moot",
        "critical",
        "03-Wednesday",
        "10",
        PRIORITIES,
        )
    # minor vs. scheduled
    tools.assert_equal(1, cmp(minor_ticket, scheduled_ticket))
    # scheduled vs. minor
    tools.assert_equal(-1, cmp(scheduled_ticket, minor_ticket))
    # emergency vs. major_ticket
    tools.assert_equal(1, cmp(major_ticket, emergency_ticket))
    # major vs. critical
    tools.assert_equal(1, cmp(major_ticket, critical_ticket))
